@@ -65,8 +65,7 @@ class KNativeConsumer(threading.Thread):
         self.logger.info("KafkaConsumer Instance Creation")
         print("KafkaConsumer Instance Creation")
         try:                
-            self.consumer=KafkaConsumer(  
-                          topics=topics,                     
+            self.consumer=KafkaConsumer(                      
                           bootstrap_servers=bootstrap_server,   
                           group_id=group_id,     
                           security_protocol=self.security_protocol,
@@ -108,10 +107,12 @@ class KNativeConsumer(threading.Thread):
         try:
             # (!?) wtf, why we need this to get partitions assigned
             # AssertionError: No partitions are currently assigned if poll() is not called
+            self.consumer.subscribe([self.topics])
+            print("**** Print the Messages 0****")
             while True:
                 # Response format is {TopicPartiton('topic1', 1): [msg1, msg2]}
                 print("**** Print the Messages 1****")
-                while not consumer.assignment():
+                while not self.consumer.assignment():
                     print("**** Print the Messages2 ****")
                     msg_pack = self.consumer.poll(timeout_ms=500)
                     print("**** Print the Messages 3****")
